@@ -10,16 +10,22 @@
 G_BEGIN_DECLS
 
 
+#ifndef GENTOO_GTK_HIDE_X11
 #define GDK_WINDOWING_X11
-#undef GDK_WINDOWING_ANDROID
+#endif
+
 #undef GDK_WINDOWING_BROADWAY
 #undef GDK_WINDOWING_MACOS
+
+#ifndef GENTOO_GTK_HIDE_WAYLAND
 #undef GDK_WINDOWING_WAYLAND
+#endif
+
 #undef GDK_WINDOWING_WIN32
 
 #define GDK_RENDERING_CAIRO
 #define GDK_RENDERING_GL
-#define GDK_RENDERING_VULKAN
+#undef GDK_RENDERING_VULKAN
 
 G_END_DECLS
 
